@@ -42,7 +42,7 @@
 arg_pat="$1"
 
 # the version of this script
-bm_version=6.6.2
+bm_version=6.8.0
 
 # CONFIGURABLE VARIABLES ---------------------------------------
 # change as needed to reflect your environment/workloads
@@ -385,33 +385,64 @@ if [ ! -r communityboards.csv ]; then
   echo ""
 fi
 
-if [ ! -r searchset_patterns_unicode.txt ]; then
-  echo "> Preparing benchmark support data..."
-  # create an index so benchmark data preparation commands can run faster
+echo "> Preparing benchmark support data..."
+# create an index so benchmark data preparation commands can run faster
+if [ ! -f "$data.idx" ]; then
   "$qsv_benchmarker_bin" index "$data"
+fi
+
+if [ ! -r data_to_exclude.csv ]; then
   echo "   data_to_exclude.csv..."
   "$qsv_benchmarker_bin" sample --seed 42 1000 "$data" -o data_to_exclude.csv
+fi
+
+if [ ! -r data_unsorted.csv ]; then
   echo "   data_unsorted.csv..."
   "$qsv_benchmarker_bin" sort --seed 42 --random --faster "$data" -o data_unsorted.csv
+fi
+
+if [ ! -r data_sorted.csv ]; then
   echo "   data_sorted.csv..."
   "$qsv_benchmarker_bin" sort "$data" -o data_sorted.csv
+fi
+
+if [ ! -r benchmark_data.xlsx ]; then
   echo "   benchmark_data.xlsx..."
   "$qsv_benchmarker_bin" to xlsx benchmark_data.xlsx "$data"
+fi
+
+if [ ! -r benchmark_data.jsonl ]; then
   echo "   benchmark_data.jsonl..."
   "$qsv_benchmarker_bin" tojsonl "$data" --output benchmark_data.jsonl
+fi
+
+if [ ! -r benchmark_data.json ]; then
   echo "   benchmark_data.json..."
   "$qsv_benchmarker_bin" sqlp --format json "$data" -q 'select * from _t_1' --infer-len 127000 --rnull-values 'N/A' --output benchmark_data.json
+fi
+
+if [ ! -r benchmark_data.csv.schema.json ]; then
   echo "   benchmark_data.schema.json..."
   "$qsv_benchmarker_bin" schema "$data" --stdout >benchmark_data.csv.schema.json
+fi
+
+if [ ! -r benchmark_data.snappy ]; then
   echo "   benchmark_data.snappy..."
   "$qsv_benchmarker_bin" snappy compress "$data" --output benchmark_data.snappy
+fi
+
+if [ ! -r searchset_patterns.txt ]; then
   echo "   searchset_patterns.txt..."
   printf "homeless\npark\nNoise\n" >searchset_patterns.txt
+fi
+
+if [ ! -r searchset_patterns_unicode.txt ]; then
   echo "   searchset_patterns_unicode.txt..."
   printf "homeless\n💩\nNoise\n" >searchset_patterns_unicode.txt
-  echo ""
 fi
 
+echo ""
+
 schema=benchmark_data.csv.schema.json
 dynenum_schema=benchmark_data-dynenum.csv.schema.json
 
@@ -605,7 +636,7 @@ run sample_bernoulli "$qsv_bin" sample --bernoulli 0.25 --seed 42 "$data"
 run sample_1000_systematic "$qsv_bin" sample 1000 --systematic random --seed 42 "$data"
 run sample_1000_stratified "$qsv_bin" sample 1000 --stratified "Agency" --seed 42 "$data"
 run sample_1000_weighted "$qsv_bin" sample 1000 --weighted \"Incident Zip\" --seed 42 "$data"
-run sample_1000_cluster "$qsv_bin" sample 1000 --cluster \"Incident Zip\" --seed 42 "$data"
+run sample_500_cluster "$qsv_bin" sample 500 --cluster \"Incident Zip\" --seed 42 "$data"
 run --index sample_100000_seeded_index "$qsv_bin" sample --seed 42 100000 "$data"
 run --index sample_100000_seeded_index_faster "$qsv_bin" sample --rng faster --seed 42 100000 "$data"
 run --index sample_100000_seeded_index_secure "$qsv_bin" sample --rng cryptosecure --seed 42 100000 "$data"
@@ -690,7 +721,7 @@ run table "$qsv_bin" table "$data"
 run template "$qsv_bin" template --template-file template.tpl "$data" >/dev/null
 run template_lookup_outdir "$qsv_bin" template --template-file template-with-cb-lookup.tpl "$data" >/dev/null
 run to_xlsx "$qsv_bin" to xlsx benchmark_work.xlsx "$data"
-run to_sqlite "$qsv_bin" to sqlite benchmark_work.db "$data"
+run to_sqlite "$qsv_bin" to sqlite benchmark_work.db "$data";rm benchmark_work.db
 run to_datapackage "$qsv_bin" to datapackage benchmark_work.json "$data"
 run tojsonl "$qsv_bin" tojsonl "$data"
 run tojsonl_batchall "$qsv_bin" tojsonl --batch 0 "$data"
