@@ -5,6 +5,8 @@ use std::{
     sync::OnceLock,
 };
 
+use cached::{DiskCacheError, RedisCacheError};
+
 /// write to stdout
 macro_rules! wout {
     ($($arg:tt)*) => ({
@@ -256,6 +258,12 @@ impl From<chrono_tz::ParseError> for CliError {
     }
 }
 
+impl From<simd_json::Error> for CliError {
+    fn from(err: simd_json::Error) -> CliError {
+        CliError::Other(format!("SimdJSON error: {err:?}"))
+    }
+}
+
 impl From<zip::result::ZipError> for CliError {
     fn from(err: zip::result::ZipError) -> CliError {
         match err {
@@ -273,3 +281,15 @@ impl From<zip::result::ZipError> for CliError {
         }
     }
 }
+
+impl From<DiskCacheError> for CliError {
+    fn from(err: DiskCacheError) -> CliError {
+        CliError::Other(format!("DiskCache error: {err:?}"))
+    }
+}
+
+impl From<RedisCacheError> for CliError {
+    fn from(err: RedisCacheError) -> CliError {
+        CliError::Other(format!("RedisCache error: {err:?}"))
+    }
+}
