@@ -7,12 +7,12 @@ Meanwhile on Linux and macOS, they may be represented as \n (LF).
 Examples:
 Pipe into qsv stats using qsv clipboard and render it as a table:
 
-  qsv clipboard | qsv stats | qsv table
+  $ qsv clipboard | qsv stats | qsv table
 
 If you want to save the output of a command to the clipboard,
 pipe into qsv clipboard using the --save or -s flag:
 
-  qsv clipboard | qsv stats | qsv clipboard -s
+  $ qsv clipboard | qsv stats | qsv clipboard -s
 
 Usage:
     qsv clipboard [options]
@@ -49,7 +49,7 @@ impl From<arboard::Error> for CliError {
                     .to_string(),
             ),
             arboard::Error::ClipboardOccupied => CliError::Other(
-                "The clipboard was unaccessible when attempting to access/use it. It may have \
+                "The clipboard was inaccessible when attempting to access/use it. It may have \
                  been held by another process/thread."
                     .to_string(),
             ),
