@@ -515,7 +515,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 // If the tolerance is a positive integer, it is tolerance number of rows.
                 // Otherwise, it is a tolerance date language spec.
                 if let Ok(numeric_tolerance) = atoi_simd::parse_pos::<u64>(tolerance.as_bytes()) {
-                    asof_options.tolerance = Some(AnyValue::UInt64(numeric_tolerance));
+                    asof_options.tolerance = Some(numeric_tolerance.into());
                 } else {
                     asof_options.tolerance_str = Some(tolerance.into());
                 }
@@ -727,8 +727,7 @@ impl JoinStruct {
                 | OptFlags::COMM_SUBPLAN_ELIM
                 | OptFlags::COMM_SUBEXPR_ELIM
                 | OptFlags::ROW_ESTIMATE
-                | OptFlags::FAST_PROJECTION
-                | OptFlags::COLLAPSE_JOINS;
+                | OptFlags::FAST_PROJECTION;
         }
 
         optflags.set(OptFlags::NEW_STREAMING, self.streaming);
@@ -776,8 +775,30 @@ impl JoinStruct {
                 // Add "_left" & "_right" suffixes to all columns before doing the non-equi join.
                 // This is necessary as the NonEqui expression is a SQL where clause and the
                 // column names for the left and right data sets are used in the expression.
-                self.left_lf = self.left_lf.select([all().name().suffix("_left")]);
-                self.right_lf = self.right_lf.select([all().name().suffix("_right")]);
+                let left_cols = self
+                    .left_lf
+                    .collect_schema()?
+                    .iter_names()
+                    .cloned()
+                    .collect::<Vec<_>>();
+                let right_cols = self
+                    .right_lf
+                    .collect_schema()?
+                    .iter_names()
+                    .cloned()
+                    .collect::<Vec<_>>();
+
+                let left_renamed_cols: Vec<Expr> = left_cols
+                    .iter()
+                    .map(|col| polars::lazy::dsl::col(col.as_str()).alias(format!("{col}_left")))
+                    .collect();
+                let right_renamed_cols: Vec<Expr> = right_cols
+                    .iter()
+                    .map(|col| polars::lazy::dsl::col(col.as_str()).alias(format!("{col}_right")))
+                    .collect();
+
+                self.left_lf = self.left_lf.select(left_renamed_cols);
+                self.right_lf = self.right_lf.select(right_renamed_cols);
 
                 self.left_lf
                     .with_optimizations(optflags)
@@ -1025,7 +1046,7 @@ impl Args {
                     if !valid_schema_exists {
                         let schema = create_schema_from_stats(input_path, args)?;
                         let stats_schema = Arc::new(schema);
-                        let stats_schema_json = serde_json::to_string_pretty(&stats_schema)?;
+                        let stats_schema_json = simd_json::to_string_pretty(&stats_schema)?;
 
                         let mut file = BufWriter::new(File::create(&schema_file)?);
                         file.write_all(stats_schema_json.as_bytes())?;
@@ -1069,8 +1090,7 @@ impl Args {
 
                     // create and cache allstring schema
                     if cache_schema == -2 {
-                        let allstring_schema_json =
-                            serde_json::to_string_pretty(&allstring_schema)?;
+                        let allstring_schema_json = simd_json::to_string_pretty(&allstring_schema)?;
 
                         let mut file = BufWriter::new(File::create(&schema_file)?);
                         file.write_all(allstring_schema_json.as_bytes())?;
@@ -1137,7 +1157,7 @@ impl Args {
 
         if create_left_schema {
             let schema = left_lf.collect_schema()?;
-            let schema_json = serde_json::to_string_pretty(&schema)?;
+            let schema_json = simd_json::to_string_pretty(&schema)?;
             let schema_file = input1_path.canonicalize()?.with_extension("pschema.json");
             let mut file = BufWriter::new(File::create(&schema_file)?);
             file.write_all(schema_json.as_bytes())?;
@@ -1171,7 +1191,7 @@ impl Args {
 
         if create_right_schema {
             let schema = right_lf.collect_schema()?;
-            let schema_json = serde_json::to_string_pretty(&schema)?;
+            let schema_json = simd_json::to_string_pretty(&schema)?;
             let schema_file = input2_path.canonicalize()?.with_extension("pschema.json");
             let mut file = BufWriter::new(File::create(&schema_file)?);
             file.write_all(schema_json.as_bytes())?;
