@@ -140,7 +140,7 @@ sample options:
                            $QSV_VERSION, $QSV_TARGET, $QSV_BIN_NAME, $QSV_KIND and $QSV_COMMAND.
                            Try to follow the syntax here -
                            https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/User-Agent
-    --timeout <secs>       Timeout for downloading URLs in seconds.
+    --timeout <secs>       Timeout for downloading URLs in seconds. If 0, no timeout is used.
                            [default: 30]
     --max-size <mb>        Maximum size of the file to download in MB before sampling.
                            Will download the entire file if not specified.
@@ -175,7 +175,6 @@ use rand::{
 use rand_hc::Hc128Rng;
 use rand_xoshiro::Xoshiro256Plus;
 use rayon::prelude::ParallelSliceMut;
-use reqwest;
 use serde::Deserialize;
 use strum_macros::EnumString;
 use tempfile::NamedTempFile;
@@ -434,21 +433,11 @@ async fn stream_bernoulli_sampling(uri: &str, args: &Args, rng_kind: &RngKind) -
         .delimiter(args.flag_delimiter)
         .writer()?;
 
-    let client = reqwest::Client::builder()
-        .user_agent(util::set_user_agent(args.flag_user_agent.clone())?)
-        .brotli(true)
-        .gzip(true)
-        .deflate(true)
-        .zstd(true)
-        .use_rustls_tls()
-        .http2_adaptive_window(true)
-        .connection_verbose(
-            log::log_enabled!(log::Level::Debug) || log::log_enabled!(log::Level::Trace),
-        )
-        .read_timeout(std::time::Duration::from_secs(
-            util::timeout_secs(args.flag_timeout.unwrap_or(30)).unwrap_or(30),
-        ))
-        .build()?;
+    let client = util::create_reqwest_async_client(
+        args.flag_user_agent.clone(),
+        util::timeout_secs(args.flag_timeout.unwrap_or(30)).unwrap_or(30) as u16,
+        Some(uri.to_string()),
+    )?;
 
     // Get the response
     let response = client.get(uri).send().await?;
