@@ -3,8 +3,8 @@ Run blazing-fast Polars SQL queries against several CSVs - replete with joins, a
 grouping, table functions, sorting, and more - working on larger than memory CSV files directly,
 without having to load it first into a database.
 
-Polars SQL is a PostgreSQL dialect, converting SQL queries to ultra-fast Polars LazyFrame
-expressions (see https://docs.pola.rs/user-guide/sql/intro/).
+Polars SQL is a PostgreSQL dialect (https://docs.pola.rs/user-guide/sql/intro/), converting SQL
+queries to ultra-fast Polars LazyFrame expressions (https://docs.pola.rs/user-guide/lazy/).
 
 For a list of SQL functions and keywords supported by Polars SQL, see
 https://docs.pola.rs/py-polars/html/reference/sql/index.html though be aware that it's for
@@ -14,44 +14,44 @@ Returns the shape of the query result (number of rows, number of columns) to std
 
 Example queries:
 
-   qsv sqlp data.csv 'select * from data where col1 > 10 order by all desc limit 20'
+  $ qsv sqlp data.csv 'select * from data where col1 > 10 order by all desc limit 20'
 
-   qsv sqlp data.csv 'select col1, col2 as friendlyname from data' --format parquet --output data.parquet
+  $ qsv sqlp data.csv 'select col1, col2 as friendlyname from data' --format parquet --output data.parquet
 
   # enclose column names with spaces in double quotes
-   qsv sqlp data.csv 'select "col 1", "col 2" from data'
+  $ qsv sqlp data.csv 'select "col 1", "col 2" from data'
 
-   qsv sqlp data.csv data2.csv 'select * from data join data2 on data.colname = data2.colname'
+  $ qsv sqlp data.csv data2.csv 'select * from data join data2 on data.colname = data2.colname'
 
-   qsv sqlp data.csv data2.csv 'SELECT col1 FROM data WHERE col1 IN (SELECT col2 FROM data2)'
+  $ qsv sqlp data.csv data2.csv 'SELECT col1 FROM data WHERE col1 IN (SELECT col2 FROM data2)'
 
   # Use dollar-quoting to avoid escaping reserved characters in literals.
-  https://www.postgresql.org/docs/current/sql-syntax-lexical.html#SQL-SYNTAX-DOLLAR-QUOTING 
-   qsv sqlp data.csv "SELECT * FROM data WHERE col1 = $$O'Reilly$$"
-   qsv sqlp data.csv 'SELECT * FROM data WHERE col1 = $SomeTag$Diane's horse "Twinkle"$SomeTag$'
+  https://www.postgresql.org/docs/current/sql-syntax-lexical.html#SQL-SYNTAX-DOLLAR-QUOTING
+  $ qsv sqlp data.csv "SELECT * FROM data WHERE col1 = $$O'Reilly$$"
+  $ qsv sqlp data.csv 'SELECT * FROM data WHERE col1 = $SomeTag$Diane's horse "Twinkle"$SomeTag$'
 
   # Unions and Joins are supported.
-   qsv sqlp data1.csv data2.csv 'SELECT * FROM data1 UNION ALL BY NAME SELECT * FROM data2'
+  $ qsv sqlp data1.csv data2.csv 'SELECT * FROM data1 UNION ALL BY NAME SELECT * FROM data2'
 
-   qsv sqlp tbl_a.csv tbl_b.csv tbl_c.csv "SELECT * FROM tbl_a \
+  $ qsv sqlp tbl_a.csv tbl_b.csv tbl_c.csv "SELECT * FROM tbl_a \
      RIGHT ANTI JOIN tbl_b USING (b) \
      LEFT SEMI JOIN tbl_c USING (c)"
 
   # use "_t_N" aliases to refer to input files, where N is the 1-based index
   # of the input file/s. For example, _t_1 refers to the first input file, _t_2
   # refers to the second input file, and so on.
-   qsv sqlp data.csv data2.csv 'select * from _t_1 join _t_2 on _t_1.colname = _t_2.colname'
+  $ qsv sqlp data.csv data2.csv 'select * from _t_1 join _t_2 on _t_1.colname = _t_2.colname'
 
-   qsv sqlp data.csv 'SELECT col1, count(*) AS cnt FROM data GROUP BY col1 ORDER BY cnt DESC, col1 ASC'
+  $ qsv sqlp data.csv 'SELECT col1, count(*) AS cnt FROM data GROUP BY col1 ORDER BY cnt DESC, col1 ASC'
 
-   qsv sqlp data.csv "select lower(col1), substr(col2, 2, 4) from data WHERE starts_with(col1, 'foo')"
+  $ qsv sqlp data.csv "select lower(col1), substr(col2, 2, 4) from data WHERE starts_with(col1, 'foo')"
 
-   qsv sqlp data.csv "select COALESCE(NULLIF(col2, ''), 'foo') from data"
+  $ qsv sqlp data.csv "select COALESCE(NULLIF(col2, ''), 'foo') from data"
 
-   qsv sqlp tbl1.csv "SELECT x FROM tbl1 WHERE x IN (SELECT y FROM tbl1)"
+  $ qsv sqlp tbl1.csv "SELECT x FROM tbl1 WHERE x IN (SELECT y FROM tbl1)"
 
   # Natural Joins are supported too! (https://www.w3resource.com/sql/joins/natural-join.php)
-   qsv sqlp data1.csv data2.csv data3.csv \
+  $ qsv sqlp data1.csv data2.csv data3.csv \
     "SELECT COLUMNS('^[^:]+$') FROM data1 NATURAL JOIN data2 NATURAL JOIN data3 ORDER BY COMPANY_ID",
 
   # Use a SQL script to run a long, complex SQL query or to run SEVERAL SQL queries.
@@ -64,85 +64,85 @@ Example queries:
   # `truncate table <table_name>;` to free up memory used by temporary tables. Otherwise,
   # the memory used by the temporary tables won't be freed until the script finishes.
   # See test_sqlp/sqlp_boston311_sql_script() for an example.
-   qsv sqlp data.csv data2.csv data3.csv data4.csv script.sql --format json --output data.json
+  $ qsv sqlp data.csv data2.csv data3.csv data4.csv script.sql --format json --output data.json
 
   # use Common Table Expressions (CTEs) using WITH to simplify complex queries
-   qsv sqlp people.csv "WITH millennials AS (SELECT * FROM people WHERE age >= 25 and age <= 40) \
+  $ qsv sqlp people.csv "WITH millennials AS (SELECT * FROM people WHERE age >= 25 and age <= 40) \
      SELECT * FROM millennials WHERE STARTS_WITH(name,'C')"
 
   # CASE statement
-   qsv sqlp data.csv "select CASE WHEN col1 > 10 THEN 'foo' WHEN col1 > 5 THEN 'bar' ELSE 'baz' END from data"
-   qsv sqlp data.csv "select CASE col*5 WHEN 10 THEN 'foo' WHEN 5 THEN 'bar' ELSE 'baz' END from _t_1"
+  $ qsv sqlp data.csv "select CASE WHEN col1 > 10 THEN 'foo' WHEN col1 > 5 THEN 'bar' ELSE 'baz' END from data"
+  $ qsv sqlp data.csv "select CASE col*5 WHEN 10 THEN 'foo' WHEN 5 THEN 'bar' ELSE 'baz' END from _t_1"
 
   # spaceship operator: "<=>" (three-way comparison operator)
   #  returns -1 if left < right, 0 if left == right, 1 if left > right
   # https://en.wikipedia.org/wiki/Three-way_comparison#Spaceship_operator
-   qsv sqlp data.csv data2.csv "select data.c2 <=> data2.c2 from data join data2 on data.c1 = data2.c1"
+  $ qsv sqlp data.csv data2.csv "select data.c2 <=> data2.c2 from data join data2 on data.c1 = data2.c1"
 
   # support ^@ ("starts with"), and ~~ (like) ,~~* (ilike),!~~ (not like),!~~* (not ilike) operators
-    qsv sqlp data.csv "select * from data WHERE col1 ^@ 'foo'"
-    qsv sqlp data.csv "select c1 ^@ 'a' AS c1_starts_with_a from data"
-    qsv sqlp data.csv "select c1 ~~* '%B' AS c1_ends_with_b_caseinsensitive from data"
+  $ qsv sqlp data.csv "select * from data WHERE col1 ^@ 'foo'"
+  $ qsv sqlp data.csv "select c1 ^@ 'a' AS c1_starts_with_a from data"
+  $ qsv sqlp data.csv "select c1 ~~* '%B' AS c1_ends_with_b_caseinsensitive from data"
 
   # support SELECT * ILIKE wildcard syntax
-    # select all columns from customers where the column contains 'a' followed by an 'e'
-    # with any characters (or no characters), in between, case-insensitive
-    # if customers.csv has columns LastName, FirstName, Address, City, State, Zip
-    # this query will return all columns for all rows except the columns that don't
-    # contain 'a' followed by an 'e' - i.e. except City and Zip
-    qsv sqlp customers.csv "SELECT * ILIKE '%a%e%' FROM customers ORDER BY LastName, FirstName"
+  # select all columns from customers where the column contains 'a' followed by an 'e'
+  # with any characters (or no characters), in between, case-insensitive
+  # if customers.csv has columns LastName, FirstName, Address, City, State, Zip
+  # this query will return all columns for all rows except the columns that don't
+  # contain 'a' followed by an 'e' - i.e. except City and Zip
+  $ qsv sqlp customers.csv "SELECT * ILIKE '%a%e%' FROM customers ORDER BY LastName, FirstName"
 
   # regex operators: "~" (contains pattern, case-sensitive); "~*" (contains pattern, case-insensitive)
   #   "!~" (does not contain pattern, case-sensitive); "!~*" (does not contain pattern, case-insensitive)
-   qsv sqlp data.csv "select * from data WHERE col1 ~ '^foo' AND col2 > 10"
-   qsv sqlp data.csv "select * from data WHERE col1 !~* 'bar$' AND col2 > 10"
+  $ qsv sqlp data.csv "select * from data WHERE col1 ~ '^foo' AND col2 > 10"
+  $ qsv sqlp data.csv "select * from data WHERE col1 !~* 'bar$' AND col2 > 10"
 
   # regexp_like function: regexp_like(<string>, <pattern>, <optional flags>)
   # returns true if <string> matches <pattern>, false otherwise
   #   <optional flags> can be one or more of the following:
   #   'c' (case-sensitive - default), 'i' (case-insensitive), 'm' (multiline)
-   qsv sqlp data.csv "select * from data WHERE regexp_like(col1, '^foo') AND col2 > 10"
+  $ qsv sqlp data.csv "select * from data WHERE regexp_like(col1, '^foo') AND col2 > 10"
   # case-insensitive regexp_like
-   qsv sqlp data.csv "select * from data WHERE regexp_like(col1, '^foo', 'i') AND col2 > 10"
+  $ qsv sqlp data.csv "select * from data WHERE regexp_like(col1, '^foo', 'i') AND col2 > 10"
 
   # regexp match using a literal pattern
-   qsv sqlp data.csv "select idx,val from data WHERE val regexp '^foo'"
+  $ qsv sqlp data.csv "select idx,val from data WHERE val regexp '^foo'"
 
   # regexp match using patterns from another column
-   qsv sqlp data.csv "select idx,val from data WHERE val regexp pattern_col"
+  $ qsv sqlp data.csv "select idx,val from data WHERE val regexp pattern_col"
 
   # use Parquet, JSONL and Arrow files in SQL queries
-   qsv sqlp data.csv "select * from data join read_parquet('data2.parquet') as t2 ON data.c1 = t2.c1"
-   qsv sqlp data.csv "select * from data join read_ndjson('data2.jsonl') as t2 on data.c1 = t2.c1"
-   qsv sqlp data.csv "select * from data join read_ipc('data2.arrow') as t2 ON data.c1 = t2.c1"
-   qsv sqlp SKIP_INPUT "select * from read_parquet('data.parquet') order by col1 desc limit 100"
-   qsv sqlp SKIP_INPUT "select * from read_ndjson('data.jsonl') as t1 join read_ipc('data.arrow') as t2 on t1.c1 = t2.c1" 
+  $ qsv sqlp data.csv "select * from data join read_parquet('data2.parquet') as t2 ON data.c1 = t2.c1"
+  $ qsv sqlp data.csv "select * from data join read_ndjson('data2.jsonl') as t2 on data.c1 = t2.c1"
+  $ qsv sqlp data.csv "select * from data join read_ipc('data2.arrow') as t2 ON data.c1 = t2.c1"
+  $ qsv sqlp SKIP_INPUT "select * from read_parquet('data.parquet') order by col1 desc limit 100"
+  $ qsv sqlp SKIP_INPUT "select * from read_ndjson('data.jsonl') as t1 join read_ipc('data.arrow') as t2 on t1.c1 = t2.c1"
 
   # you can also directly load CSVs using the Polars read_csv() SQL function. This is useful when
   # you want to bypass the regular CSV parser (with SKIP_INPUT) and use Polars' multithreaded,
   # mem-mapped CSV parser instead - making for dramatically faster queries at the cost of CSV parser
   # configurability (i.e. limited to comma delimiter, no CSV comments, etc.).
-   qsv sqlp SKIP_INPUT "select * from read_csv('data.csv') order by col1 desc limit 100"
+  $ qsv sqlp SKIP_INPUT "select * from read_csv('data.csv') order by col1 desc limit 100"
 
-   # note that you can also use read_csv() to read compressed files directly
-   # gzip, zstd and zlib automatic decompression are supported
-   qsv sqlp SKIP_INPUT "select * from read_csv('data.csv.gz')"
-   qsv sqlp SKIP_INPUT "select * from read_csv('data.csv.zst')"
-   qsv sqlp SKIP_INPUT "select * from read_csv('data.csv.zlib')"
+  # note that you can also use read_csv() to read compressed files directly
+  # gzip, zstd and zlib automatic decompression are supported
+  $ qsv sqlp SKIP_INPUT "select * from read_csv('data.csv.gz')"
+  $ qsv sqlp SKIP_INPUT "select * from read_csv('data.csv.zst')"
+  $ qsv sqlp SKIP_INPUT "select * from read_csv('data.csv.zlib')"
 
   # apart from using Polar's table functions, you can also use SKIP_INPUT when the SELECT
   # statement doesn't require an input file
-   qsv sqlp SKIP_INPUT "SELECT 1 AS one, '2' AS two, 3.0 AS three"
+  $ qsv sqlp SKIP_INPUT "SELECT 1 AS one, '2' AS two, 3.0 AS three"
 
   # use stdin as input
-   cat data.csv | qsv sqlp - 'select * from stdin'
-   cat data.csv | qsv sqlp - data2.csv 'select * from stdin join data2 on stdin.col1 = data2.col1'
+  $ cat data.csv | qsv sqlp - 'select * from stdin'
+  $ cat data.csv | qsv sqlp - data2.csv 'select * from stdin join data2 on stdin.col1 = data2.col1'
 
   # automatic snappy decompression/compression
-   qsv sqlp data.csv.sz 'select * from data where col1 > 10' --output result.csv.sz
+  $ qsv sqlp data.csv.sz 'select * from data where col1 > 10' --output result.csv.sz
 
   # explain query plan
-   qsv sqlp data.csv 'explain select * from data where col1 > 10 order by col2 desc limit 20'
+  $ qsv sqlp data.csv 'explain select * from data where col1 > 10 order by col2 desc limit 20'
 
 For more examples, see https://github.com/dathere/qsv/blob/master/tests/test_sqlp.rs.
 
@@ -198,8 +198,8 @@ sqlp options:
                               Polars "table" with the same file stem.
                               If specified and the schema file/s do not exist, it will check if a
                               stats cache is available. If so, it will use it to derive a Polars schema
-                              and save it. If there's no stats cache, it will infer the schema 
-                              using --infer-len and save the inferred schemas. 
+                              and save it. If there's no stats cache, it will infer the schema
+                              using --infer-len and save the inferred schemas.
                               Each schema file will have the same file stem as the corresponding
                               input file, with the extension ".pschema.json"
                               (data.csv's Polars schema file will be data.pschema.json)
@@ -212,7 +212,7 @@ sqlp options:
                               The valid types are: `Boolean`, `UInt8`, `UInt16`, `UInt32`, `UInt64`, `Int8`,
                               `Int16`, `Int32`, `Int64`, `Float32`, `Float64`, `String`, `Date`, `Datetime`,
                               `Duration`, `Time`, `Null`, `Categorical`, `Decimal` and `Enum`.
-                              
+
     --streaming               Use streaming mode when parsing CSVs. This will use less memory
                               but will be slower. Only use this when you get out of memory errors.
     --low-memory              Use low memory mode when parsing CSVs. This will use less memory
@@ -265,7 +265,7 @@ sqlp options:
                               Higher compression levels are slower.
                               The zstd default is 3, and the gzip default is 6.
     --statistics              Compute column statistics when writing parquet files.
-    
+
 Common options:
     -h, --help             Display this message
     -o, --output <file>    Write output to <file> instead of stdout.
@@ -457,10 +457,11 @@ impl OutputMode {
                         .parse()
                         .unwrap_or(ArrowCompression::Uncompressed);
 
+                    #[allow(clippy::default_trait_access)]
                     let ipc_compression: Option<IpcCompression> = match compression {
                         ArrowCompression::Uncompressed => None,
                         ArrowCompression::Lz4 => Some(IpcCompression::LZ4),
-                        ArrowCompression::Zstd => Some(IpcCompression::ZSTD),
+                        ArrowCompression::Zstd => Some(IpcCompression::ZSTD(Default::default())),
                     };
 
                     IpcWriter::new(&mut w)
@@ -643,8 +644,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             | OptFlags::COMM_SUBPLAN_ELIM
             | OptFlags::COMM_SUBEXPR_ELIM
             | OptFlags::ROW_ESTIMATE
-            | OptFlags::FAST_PROJECTION
-            | OptFlags::COLLAPSE_JOINS;
+            | OptFlags::FAST_PROJECTION;
     }
 
     optflags.set(OptFlags::NEW_STREAMING, args.flag_streaming);
@@ -882,7 +882,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             // update the pschema.json file, if necessary
             if create_schema {
                 let schema = lf.collect_schema()?;
-                let schema_json = serde_json::to_string_pretty(&schema)?;
+                let schema_json = simd_json::to_string_pretty(&schema)?;
 
                 let schema_file = table.canonicalize()?.with_extension("pschema.json");
                 let mut file = BufWriter::new(File::create(&schema_file)?);
