@@ -210,17 +210,12 @@ fn download_lookup_table(
     cache_csv_last_modified: Option<SystemTime>,
     opts: &LookupTableOptions,
 ) -> Result<(), Box<dyn std::error::Error>> {
-    let client = Client::builder()
-        .user_agent(crate::util::set_user_agent(None).unwrap())
-        .brotli(true)
-        .gzip(true)
-        .deflate(true)
-        .zstd(true)
-        .use_rustls_tls()
-        .http2_adaptive_window(true)
-        .connection_verbose(log::log_enabled!(log::Level::Trace))
-        .timeout(std::time::Duration::from_secs(opts.timeout_secs as u64))
-        .build()?;
+    let client = crate::util::create_reqwest_blocking_client(
+        None,
+        opts.timeout_secs,
+        Some(lookup_table_uri.to_string()),
+    )
+    .map_err(|e| Box::new(std::io::Error::other(e.to_string())))?;
 
     let now = SystemTime::now();
     let now_dt_utc: chrono::DateTime<chrono::Utc> = now.into();
