@@ -27,6 +27,7 @@
         clippy::use_self,
         clippy::cognitive_complexity,
         clippy::option_if_let_else,
+        clippy::implicit_clone,
     ),
     warn(
         clippy::missing_asserts_for_indexing,
@@ -49,7 +50,7 @@ use crate::{
 #[global_allocator]
 static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
-#[cfg(feature = "jemallocator")]
+#[cfg(feature = "tikv-jemallocator")]
 #[global_allocator]
 static GLOBAL: jemallocator::Jemalloc = jemallocator::Jemalloc;
 
