@@ -2582,7 +2582,7 @@ fn apply_ops_whatlang_high_confidence_threshold() {
              meva més gran preocupació.",
             "Cat(1.000)"
         ],
-        svec!["amikor a Fafnir ", "Por(0.011)?"],
+        svec!["amikor a Fafnir ", "Cym(0.210)?"],
         svec![
             "Showing that even in the modern warfare of the 1930s and 1940s, the dilapidated \
              fortifications still had defensive usefulness.",
@@ -2611,7 +2611,7 @@ fn apply_ops_whatlang_high_confidence_threshold() {
 }
 
 #[test]
-fn apply_ops_whatlang_low_confidence_threshold() {
+fn apply_ops_whatlang_show_confidence_threshold() {
     let wrk = Workdir::new("apply");
     wrk.create(
         "data.csv",
@@ -2651,7 +2651,7 @@ fn apply_ops_whatlang_low_confidence_threshold() {
         .arg("whatlang")
         .arg("description")
         .arg("--comparand")
-        .arg("0.03")
+        .arg("0.03?")
         .arg("--new-column")
         .arg("language")
         .arg("data.csv");
@@ -2662,37 +2662,37 @@ fn apply_ops_whatlang_low_confidence_threshold() {
         svec![
             "Y así mismo, aunque no son tan ágiles en el suelo como el vampiro común, son muy \
              competentes al escalar por las ramas.",
-            "Spa"
+            "Spa(1.000)"
         ],
-        svec!["See notes.", "Cat"],
+        svec!["See notes.", "Cat(0.031)"],
         svec![
             "Aquest és l’honor més gran que he rebut a la meva vida. La pau ha estat sempre la \
              meva més gran preocupació.",
-            "Cat"
+            "Cat(1.000)"
         ],
-        svec!["amikor a Fafnir ", "Por(0.011)?"],
+        svec!["amikor a Fafnir ", "Cym(0.210)"],
         svec![
             "Showing that even in the modern warfare of the 1930s and 1940s, the dilapidated \
              fortifications still had defensive usefulness.",
-            "Eng"
+            "Eng(1.000)"
         ],
         svec![
             "民國卅八年（ 1949年 ）， 從南京經 廣州 、 香港返回 香日德。 1950年6月 \
              ，受十世班禪派遣， 前往西安代表班禪向彭德懷投誠 。",
-            "Cmn"
+            "Cmn(1.000)"
         ],
         svec![
             "Rust（ラスト）は並列かつマルチパラダイムのプログラミング言語である",
-            "Jpn"
+            "Jpn(1.000)"
         ],
         svec![
             "Мой дядя самых честных правил, Когда не в шутку занемог, Он уважать себя заставил И \
              лучше выдумать не мог.",
-            "Rus"
+            "Rus(1.000)"
         ],
         svec![
             "Kamusta na, pare!?! Matagal na tayong di nagkita! Ilang taon na since high school?!",
-            "Tgl"
+            "Tgl(1.000)"
         ],
     ];
     assert_eq!(got, expected);
