@@ -23,7 +23,7 @@ fn table() {
     cmd.arg("in.csv");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(&*got, EXPECTED_TABLE)
+    assert_eq!(&*got, EXPECTED_TABLE)
 }
 
 #[test]
@@ -36,7 +36,7 @@ fn table_tsv() {
     cmd.arg("in.tsv");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(&*got, EXPECTED_TABLE)
+    assert_eq!(&*got, EXPECTED_TABLE)
 }
 
 #[test]
@@ -49,7 +49,7 @@ fn table_ssv() {
     cmd.arg("in.ssv");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(&*got, EXPECTED_TABLE)
+    assert_eq!(&*got, EXPECTED_TABLE)
 }
 
 #[test]
@@ -63,7 +63,7 @@ fn table_default() {
     cmd.arg("in.file");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(&*got, EXPECTED_TABLE)
+    assert_eq!(&*got, EXPECTED_TABLE)
 }
 
 #[test]
@@ -77,7 +77,7 @@ fn table_pipe_delimiter_env() {
     cmd.arg("in.file");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(&*got, EXPECTED_TABLE)
+    assert_eq!(&*got, EXPECTED_TABLE)
 }
 
 #[test]
@@ -90,7 +90,7 @@ fn table_pipe_delimiter() {
     cmd.arg("--delimiter").arg("|").arg("in.file");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(&*got, EXPECTED_TABLE)
+    assert_eq!(&*got, EXPECTED_TABLE)
 }
 
 #[test]
@@ -103,7 +103,7 @@ fn invalid_delimiter_len() {
     cmd.arg("--delimiter").arg("||").arg("in.file");
 
     let got: String = wrk.output_stderr(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         &*got,
         "Could not convert '||' to a single ASCII character.\n"
     )
@@ -120,7 +120,7 @@ fn table_right_align() {
     cmd.arg("in.csv");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         &*got,
         concat!("     h1   h2  h3\n", "abcdefg    a  a\n", "      a  abc  z",)
     );
@@ -137,8 +137,46 @@ fn table_center_align() {
     cmd.arg("in.csv");
 
     let got: String = wrk.stdout(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         &*got,
         concat!("  h1     h2   h3\n", "abcdefg   a   a\n", "   a     abc  z",)
     );
 }
+
+#[test]
+fn table_leftendtab_align() {
+    let wrk = Workdir::new("table");
+    wrk.create("in.csv", data());
+
+    let mut cmd = wrk.command("table");
+    cmd.arg("--align");
+    cmd.arg("leftendtab");
+    cmd.arg("in.csv");
+
+    let got: String = wrk.stdout(&mut cmd);
+    // leftendtab alignment should left-align content with tab-separated columns
+    // This creates a TSV-like format that's both human-readable and machine-parseable
+    assert_eq!(
+        &*got,
+        "h1      \th2  \th3\nabcdefg \ta   \ta\na       \tabc \tz"
+    );
+}
+
+#[test]
+fn table_leftfwf_align() {
+    let wrk = Workdir::new("table");
+    wrk.create("in.csv", data());
+
+    let mut cmd = wrk.command("table");
+    cmd.arg("--align");
+    cmd.arg("leftfwf");
+    cmd.arg("in.csv");
+
+    let got: String = wrk.stdout(&mut cmd);
+    // leftfwf alignment should be similar to left but with the first line being a comment
+    // that enumerates the position (1-based, comma-separated) of each column
+    assert_eq!(
+        &*got,
+        "#1,10,15\nh1       h2   h3\nabcdefg  a    a\na        abc  z"
+    );
+}
