@@ -94,12 +94,7 @@ fn validate_good_csv_pretty_json() {
 
     let got: String = wrk.stdout(&mut cmd);
     let expected = r#"{
-  "delimiter_char": ",",
-  "header_row": true,
-  "quote_char": "\"",
-  "num_records": 3,
-  "num_fields": 3,
-  "fields": [
+  "delimiter_char": ",","header_row": true,"quote_char": "\"","num_records": 3,"num_fields": 3,"fields": [
     "title",
     "name",
     "real age (earth years)"
@@ -1569,3 +1564,1017 @@ fn validate_invalid_json_schema_file() {
     let got = wrk.output_stderr(&mut cmd);
     assert_eq!(got, "Invalid JSON Schema.\n");
 }
+
+#[test]
+fn validate_with_fancy_regex() {
+    let wrk = Workdir::new("validate_with_fancy_regex").flexible(true);
+
+    // Create test data with passwords that need to meet specific criteria
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["username", "password"],
+            svec!["user1", "Password123!"], // Valid: has uppercase, lowercase, digit, special char
+            svec!["user2", "password123"],  // Invalid: no uppercase, no special char
+            svec!["user3", "PASSWORD123!"], // Invalid: no lowercase
+            svec!["user4", "Password!"],    // Invalid: no digit
+            svec!["user5", "Pass123"],      // Invalid: no special char
+        ],
+    );
+
+    // Create schema with a regex pattern that requires fancy regex support
+    // This regex uses look-ahead assertions (?=...) to ensure password contains:
+    // - at least one uppercase letter
+    // - at least one lowercase letter
+    // - at least one digit
+    // - at least one special character
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "username": { "type": "string" },
+                "password": { 
+                    "type": "string",
+                    "pattern": "^(?=.*[A-Z])(?=.*[a-z])(?=.*\\d)(?=.*[!@#$%^&*()_+\\-=\\[\\]{};':\"\\\\|,.<>\\/?]).{8,}$"
+                }
+            }
+        }"#,
+    );
+
+    // Run validate command WITHOUT fancy-regex flag (should fail)
+    let mut cmd = wrk.command("validate");
+    cmd.arg("data.csv").arg("schema.json");
+
+    // This should fail because the regex pattern uses look-ahead assertions
+    // which are not supported by the default regex engine
+    wrk.assert_err(&mut cmd);
+
+    // Run validate command WITH fancy-regex flag (should work)
+    let mut cmd_fancy = wrk.command("validate");
+    cmd_fancy
+        .arg("data.csv")
+        .arg("schema.json")
+        .arg("--fancy-regex");
+    wrk.output(&mut cmd_fancy);
+
+    // we still get an error here as the test data is invalid,
+    // not because of the regex engine
+    wrk.assert_err(&mut cmd_fancy);
+    let got = wrk.output_stderr(&mut cmd_fancy);
+    assert_eq!(got, "4 out of 5 records invalid.\n");
+
+    // Check validation-errors.tsv - should show 4 invalid passwords
+    let validation_errors: String = wrk.from_str(&wrk.path("data.csv.validation-errors.tsv"));
+
+    // The error messages should indicate pattern validation failures
+    assert!(validation_errors.contains("password"));
+    // Check for the specific error message format used by jsonschema
+    assert!(validation_errors.contains("does not match"));
+
+    // Check valid records - should only contain the valid password
+    let valid_records: Vec<Vec<String>> = wrk.read_csv("data.csv.valid");
+    let expected_valid = vec![svec!["user1", "Password123!"]];
+    assert_eq!(valid_records, expected_valid);
+
+    // Check invalid records - should contain the 4 invalid passwords
+    let invalid_records: Vec<Vec<String>> = wrk.read_csv("data.csv.invalid");
+    let expected_invalid = vec![
+        svec!["user2", "password123"],
+        svec!["user3", "PASSWORD123!"],
+        svec!["user4", "Password!"],
+        svec!["user5", "Pass123"],
+    ];
+    assert_eq!(invalid_records, expected_invalid);
+}
+
+#[test]
+fn validate_schema_subcommand_valid_schema() {
+    let wrk = Workdir::new("validate_schema_subcommand_valid_schema").flexible(true);
+
+    // Create a valid JSON Schema
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "name": { "type": "string" },
+                "email": { 
+                    "type": "string",
+                    "format": "email"
+                },
+                "age": { 
+                    "type": "integer",
+                    "minimum": 0,
+                    "maximum": 150
+                }
+            },
+            "required": ["id", "name"]
+        }"#,
+    );
+
+    // Run validate schema command
+    let mut cmd = wrk.command("validate");
+    cmd.arg("schema").arg("schema.json");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "Valid JSON Schema.\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_schema_subcommand_invalid_schema() {
+    let wrk = Workdir::new("validate_schema_subcommand_invalid_schema").flexible(true);
+
+    // Create an invalid JSON Schema (invalid type)
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "invalid_type" },
+                "name": { "type": "string" }
+            }
+        }"#,
+    );
+
+    // Run validate schema command
+    let mut cmd = wrk.command("validate");
+    cmd.arg("schema").arg("schema.json");
+
+    wrk.assert_err(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "Invalid JSON Schema.\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_schema_subcommand_invalid_draft() {
+    let wrk = Workdir::new("validate_schema_subcommand_invalid_draft").flexible(true);
+
+    // Create a schema with invalid draft version
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-25/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" }
+            }
+        }"#,
+    );
+
+    // Run validate schema command
+    let mut cmd = wrk.command("validate");
+    cmd.arg("schema").arg("schema.json");
+
+    wrk.assert_err(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "JSON Schema Meta-Reference Error: Unknown specification: https://json-schema.org/draft/2020-25/schema\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_schema_subcommand_no_schema_file() {
+    let wrk = Workdir::new("validate_schema_subcommand_no_schema_file").flexible(true);
+
+    // Run validate schema command without providing a schema file
+    let mut cmd = wrk.command("validate");
+    cmd.arg("schema");
+
+    wrk.assert_err(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "No JSON Schema file supplied.\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_schema_subcommand_with_no_format_validation() {
+    let wrk = Workdir::new("validate_schema_subcommand_with_no_format_validation").flexible(true);
+
+    // Create a schema with format validation
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "email": { 
+                    "type": "string",
+                    "format": "email"
+                },
+                "uri": { 
+                    "type": "string",
+                    "format": "uri"
+                },
+                "currency": { 
+                    "type": "string",
+                    "format": "currency"
+                }
+            }
+        }"#,
+    );
+
+    // Run validate schema command with --no-format-validation
+    let mut cmd = wrk.command("validate");
+    cmd.arg("schema")
+        .arg("--no-format-validation")
+        .arg("schema.json");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "Valid JSON Schema.\n";
+    assert_eq!(got, expected);
+}
+
+// Note: --quiet flag test removed due to command parsing issues
+
+#[test]
+fn validate_with_no_format_validation_success() {
+    let wrk = Workdir::new("validate_with_no_format_validation_success").flexible(true);
+
+    // Create test data with invalid format values that would normally fail validation
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["id", "name", "email", "website", "currency"],
+            svec!["1", "John Doe", "not-an-email", "not-a-url", "not-currency"],
+            svec![
+                "2",
+                "Jane Smith",
+                "also-not-email",
+                "also-not-url",
+                "also-not-currency"
+            ],
+        ],
+    );
+
+    // Create schema with format validation
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "name": { "type": "string" },
+                "email": { 
+                    "type": "string",
+                    "format": "email"
+                },
+                "website": { 
+                    "type": "string",
+                    "format": "uri"
+                },
+                "currency": { 
+                    "type": "string",
+                    "format": "currency"
+                }
+            }
+        }"#,
+    );
+
+    // Run validation WITH format validation (should fail)
+    let mut cmd_with_format = wrk.command("validate");
+    cmd_with_format.arg("data.csv").arg("schema.json");
+    wrk.output(&mut cmd_with_format);
+
+    wrk.assert_err(&mut cmd_with_format);
+
+    // Check that format validation errors are present
+    let validation_errors = wrk
+        .read_to_string("data.csv.validation-errors.tsv")
+        .unwrap();
+    assert!(validation_errors.contains("is not a \"email\""));
+    assert!(validation_errors.contains("is not a \"uri\""));
+    assert!(validation_errors.contains("is not a \"currency\""));
+
+    // Clean up output files for next test
+    let _ = std::fs::remove_file(wrk.path("data.csv.valid"));
+    let _ = std::fs::remove_file(wrk.path("data.csv.invalid"));
+    let _ = std::fs::remove_file(wrk.path("data.csv.validation-errors.tsv"));
+
+    // Run validation WITHOUT format validation (should succeed)
+    let mut cmd_no_format = wrk.command("validate");
+    cmd_no_format
+        .arg("--no-format-validation")
+        .arg("data.csv")
+        .arg("schema.json");
+
+    wrk.assert_success(&mut cmd_no_format);
+
+    // Should not create any error files since all records are valid
+    // when format validation is disabled
+    assert!(!wrk.path("data.csv.invalid").exists());
+    assert!(!wrk.path("data.csv.validation-errors.tsv").exists());
+
+    let got: String = wrk.output_stderr(&mut cmd_no_format);
+    let expected = "All 2 records valid.\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_with_no_format_validation_mixed_errors() {
+    let wrk = Workdir::new("validate_with_no_format_validation_mixed_errors").flexible(true);
+
+    // Create test data with both format errors and structural errors
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["id", "name", "email", "age"],
+            svec!["1", "John Doe", "not-an-email", "25"], // Format error only
+            svec!["2", "Jane Smith", "jane@example.com", "not-a-number"], // Type error
+            svec!["3", "Bob Wilson", "bob@example.com", "30"], // Valid
+        ],
+    );
+
+    // Create schema with both format and type validation
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "name": { "type": "string" },
+                "email": { 
+                    "type": "string",
+                    "format": "email"
+                },
+                "age": { 
+                    "type": "integer",
+                    "minimum": 0,
+                    "maximum": 150
+                }
+            }
+        }"#,
+    );
+
+    // Run validation WITH format validation
+    let mut cmd_with_format = wrk.command("validate");
+    cmd_with_format.arg("data.csv").arg("schema.json");
+    wrk.output(&mut cmd_with_format);
+
+    wrk.assert_err(&mut cmd_with_format);
+
+    // Should have both format and type errors
+    let validation_errors = wrk
+        .read_to_string("data.csv.validation-errors.tsv")
+        .unwrap();
+    assert!(validation_errors.contains("is not a \"email\"")); // Format error
+    assert!(validation_errors.contains("Can't cast to Integer")); // Type error
+
+    // Clean up output files for next test
+    let _ = std::fs::remove_file(wrk.path("data.csv.valid"));
+    let _ = std::fs::remove_file(wrk.path("data.csv.invalid"));
+    let _ = std::fs::remove_file(wrk.path("data.csv.validation-errors.tsv"));
+
+    // Run validation WITHOUT format validation
+    let mut cmd_no_format = wrk.command("validate");
+    cmd_no_format
+        .arg("--no-format-validation")
+        .arg("data.csv")
+        .arg("schema.json");
+    wrk.output(&mut cmd_no_format);
+
+    wrk.assert_err(&mut cmd_no_format);
+
+    // Should only have type errors, no format errors
+    let validation_errors_no_format = wrk
+        .read_to_string("data.csv.validation-errors.tsv")
+        .unwrap();
+    assert!(!validation_errors_no_format.contains("is not a \"email\"")); // No format error
+    assert!(validation_errors_no_format.contains("Can't cast to Integer")); // Still has type error
+
+    // Check valid records - should include the record with only format errors
+    let valid_records: Vec<Vec<String>> = wrk.read_csv("data.csv.valid");
+    let expected_valid = vec![
+        svec!["1", "John Doe", "not-an-email", "25"], // Now valid (format ignored)
+        svec!["3", "Bob Wilson", "bob@example.com", "30"], // Still valid
+    ];
+    assert_eq!(valid_records, expected_valid);
+
+    // Check invalid records - should only include the record with type errors
+    let invalid_records: Vec<Vec<String>> = wrk.read_csv("data.csv.invalid");
+    let expected_invalid = vec![svec!["2", "Jane Smith", "jane@example.com", "not-a-number"]];
+    assert_eq!(invalid_records, expected_invalid);
+}
+
+#[test]
+fn validate_schema_subcommand_with_invalid_format_validation() {
+    let wrk =
+        Workdir::new("validate_schema_subcommand_with_invalid_format_validation").flexible(true);
+
+    // Create a schema with invalid format validation that would normally fail
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "email": { 
+                    "type": "string",
+                    "format": "invalid_format"
+                }
+            }
+        }"#,
+    );
+
+    // Run validate schema command WITHOUT --no-format-validation (should fail)
+    let mut cmd_with_format = wrk.command("validate");
+    cmd_with_format.arg("schema").arg("schema.json");
+
+    wrk.assert_err(&mut cmd_with_format);
+
+    // Run validate schema command WITH --no-format-validation (should succeed)
+    let mut cmd_no_format = wrk.command("validate");
+    cmd_no_format
+        .arg("schema")
+        .arg("--no-format-validation")
+        .arg("schema.json");
+
+    wrk.assert_success(&mut cmd_no_format);
+
+    let got: String = wrk.output_stderr(&mut cmd_no_format);
+    let expected = "Valid JSON Schema.\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_schema_subcommand_with_url_schema() {
+    let wrk = Workdir::new("validate_schema_subcommand_with_url_schema").flexible(true);
+
+    // Test with a remote schema URL
+    let mut cmd = wrk.command("validate");
+    cmd.arg("schema")
+        .arg("https://raw.githubusercontent.com/dathere/qsv/master/resources/test/public-toilets-schema.json");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "Valid JSON Schema.\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_schema_subcommand_with_invalid_url_schema() {
+    let wrk = Workdir::new("validate_schema_subcommand_with_invalid_url_schema").flexible(true);
+
+    // Test with an invalid remote schema URL
+    let mut cmd = wrk.command("validate");
+    cmd.arg("schema")
+        .arg("https://raw.githubusercontent.com/dathere/qsv/master/nonexistent-schema.json");
+
+    wrk.assert_err(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    assert!(
+        got.contains("Cannot compile JSONschema")
+            || got.contains("io error")
+            || got.contains("timeout")
+            || got.contains("JSON error")
+    );
+}
+
+#[test]
+fn validate_with_no_format_validation_and_dynamic_enum() {
+    let wrk = Workdir::new("validate_with_no_format_validation_and_dynamic_enum").flexible(true);
+
+    // Create lookup file
+    wrk.create(
+        "lookup.csv",
+        vec![
+            svec!["code", "name"],
+            svec!["A1", "Apple"],
+            svec!["B2", "Banana"],
+        ],
+    );
+
+    // Create test data
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["id", "product", "email"],
+            svec!["1", "Apple", "not-an-email"], // Valid product, invalid email format
+            svec!["2", "Orange", "valid@email.com"], // Invalid product, valid email format
+        ],
+    );
+
+    // Create schema with both dynamicEnum and format validation
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "product": { 
+                    "type": "string",
+                    "dynamicEnum": "lookup.csv|name"
+                },
+                "email": { 
+                    "type": "string",
+                    "format": "email"
+                }
+            }
+        }"#,
+    );
+
+    // Run validation WITH format validation
+    let mut cmd_with_format = wrk.command("validate");
+    cmd_with_format.arg("data.csv").arg("schema.json");
+    wrk.output(&mut cmd_with_format);
+
+    wrk.assert_err(&mut cmd_with_format);
+
+    // Should have both dynamicEnum and format errors
+    let validation_errors = wrk
+        .read_to_string("data.csv.validation-errors.tsv")
+        .unwrap();
+    assert!(validation_errors.contains("is not a valid dynamicEnum value")); // dynamicEnum error
+    assert!(validation_errors.contains("is not a \"email\"")); // Format error
+
+    // Clean up output files for next test
+    let _ = std::fs::remove_file(wrk.path("data.csv.valid"));
+    let _ = std::fs::remove_file(wrk.path("data.csv.invalid"));
+    let _ = std::fs::remove_file(wrk.path("data.csv.validation-errors.tsv"));
+
+    // Run validation WITHOUT format validation
+    let mut cmd_no_format = wrk.command("validate");
+    cmd_no_format
+        .arg("--no-format-validation")
+        .arg("data.csv")
+        .arg("schema.json");
+    wrk.output(&mut cmd_no_format);
+
+    wrk.assert_err(&mut cmd_no_format);
+
+    // Should only have dynamicEnum errors, no format errors
+    let validation_errors_no_format = wrk
+        .read_to_string("data.csv.validation-errors.tsv")
+        .unwrap();
+    assert!(validation_errors_no_format.contains("is not a valid dynamicEnum value")); // Still has dynamicEnum error
+    assert!(!validation_errors_no_format.contains("is not a \"email\"")); // No format error
+
+    // Check valid records - should include the record with only format errors
+    let valid_records: Vec<Vec<String>> = wrk.read_csv("data.csv.valid");
+    let expected_valid = vec![svec!["1", "Apple", "not-an-email"]]; // Now valid (format ignored)
+    assert_eq!(valid_records, expected_valid);
+
+    // Check invalid records - should only include the record with dynamicEnum errors
+    let invalid_records: Vec<Vec<String>> = wrk.read_csv("data.csv.invalid");
+    let expected_invalid = vec![svec!["2", "Orange", "valid@email.com"]];
+    assert_eq!(invalid_records, expected_invalid);
+}
+
+#[test]
+fn validate_multiple_files_rfc4180() {
+    let wrk = Workdir::new("validate_multiple_files_rfc4180").flexible(true);
+
+    // Create multiple test CSV files
+    wrk.create(
+        "file1.csv",
+        vec![
+            svec!["id", "name", "age"],
+            svec!["1", "John", "25"],
+            svec!["2", "Jane", "30"],
+        ],
+    );
+
+    wrk.create(
+        "file2.csv",
+        vec![
+            svec!["product", "price", "stock"],
+            svec!["Laptop", "999.99", "50"],
+            svec!["Phone", "699.99", "100"],
+        ],
+    );
+
+    wrk.create(
+        "file3.csv",
+        vec![
+            svec!["city", "country", "population"],
+            svec!["New York", "USA", "8000000"],
+            svec!["London", "UK", "9000000"],
+        ],
+    );
+
+    // Test validating multiple files
+    let mut cmd = wrk.command("validate");
+    cmd.arg("file1.csv").arg("file2.csv").arg("file3.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+
+    // The Extended Input Support should work and show a summary
+    assert!(got.contains("✅ All 3 files are valid."));
+}
+
+#[test]
+fn validate_multiple_files_with_invalid() {
+    let wrk = Workdir::new("validate_multiple_files_with_invalid").flexible(true);
+
+    // Create one valid file
+    wrk.create(
+        "valid.csv",
+        vec![svec!["id", "name"], svec!["1", "John"], svec!["2", "Jane"]],
+    );
+
+    // Create one invalid file (unequal field count)
+    wrk.create(
+        "invalid.csv",
+        vec![
+            svec!["id", "name", "age"],
+            svec!["1", "John", "25"],
+            svec!["2", "Jane"], // Missing age field
+        ],
+    );
+
+    // Test validating multiple files with one invalid
+    let mut cmd = wrk.command("validate");
+    cmd.arg("valid.csv").arg("invalid.csv");
+
+    wrk.assert_err(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+
+    // The output should contain error information and summary
+    assert!(got.contains("❌ 1 out of 2 files are invalid."));
+}
+
+#[test]
+fn validate_directory() {
+    let wrk = Workdir::new("validate_directory").flexible(true);
+
+    // Create a subdirectory with CSV files
+    let _ = wrk.create_subdir("data");
+
+    // Create files in the subdirectory
+    wrk.create(
+        "data/file1.csv",
+        vec![svec!["id", "name"], svec!["1", "John"], svec!["2", "Jane"]],
+    );
+
+    wrk.create(
+        "data/file2.csv",
+        vec![
+            svec!["product", "price"],
+            svec!["Laptop", "999.99"],
+            svec!["Phone", "699.99"],
+        ],
+    );
+
+    // Test validating a directory
+    let mut cmd = wrk.command("validate");
+    cmd.arg("data");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    // The Extended Input Support should work for directories
+    assert!(got.contains("✅ All 2 files are valid."));
+}
+
+#[test]
+fn validate_infile_list() {
+    let wrk = Workdir::new("validate_infile_list").flexible(true);
+
+    // Create individual CSV files
+    wrk.create(
+        "file1.csv",
+        vec![svec!["id", "name"], svec!["1", "John"], svec!["2", "Jane"]],
+    );
+
+    wrk.create(
+        "file2.csv",
+        vec![
+            svec!["product", "price"],
+            svec!["Laptop", "999.99"],
+            svec!["Phone", "699.99"],
+        ],
+    );
+
+    // Create an infile-list file
+    wrk.create(
+        "filelist.infile-list",
+        vec![svec!["file1.csv"], svec!["file2.csv"]],
+    );
+
+    // Test validating using infile-list
+    let mut cmd = wrk.command("validate");
+    cmd.arg("filelist.infile-list");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    assert!(got.contains("✅ All 2 files are valid."));
+}
+
+#[test]
+fn validate_multiple_files_json_output() {
+    let wrk = Workdir::new("validate_multiple_files_json_output").flexible(true);
+
+    // Create multiple test CSV files
+    wrk.create(
+        "file1.csv",
+        vec![svec!["id", "name"], svec!["1", "John"], svec!["2", "Jane"]],
+    );
+
+    wrk.create(
+        "file2.csv",
+        vec![
+            svec!["product", "price"],
+            svec!["Laptop", "999.99"],
+            svec!["Phone", "699.99"],
+        ],
+    );
+
+    // Test validating multiple files with JSON output
+    let mut cmd = wrk.command("validate");
+    cmd.arg("--json").arg("file1.csv").arg("file2.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    assert!(got.contains("✅ All 2 files are valid."));
+
+    // Check that JSON output is produced for each file
+    let output = wrk.output(&mut cmd);
+    let stdout_str = String::from_utf8_lossy(&output.stdout);
+    assert!(stdout_str.contains("\"delimiter_char\":\",\""));
+    assert!(stdout_str.contains("\"num_records\":2"));
+}
+
+#[test]
+fn validate_multiple_files_pretty_json_output() {
+    let wrk = Workdir::new("validate_multiple_files_pretty_json_output").flexible(true);
+
+    // Create multiple test CSV files
+    wrk.create(
+        "file1.csv",
+        vec![svec!["id", "name"], svec!["1", "John"], svec!["2", "Jane"]],
+    );
+
+    wrk.create(
+        "file2.csv",
+        vec![
+            svec!["product", "price"],
+            svec!["Laptop", "999.99"],
+            svec!["Phone", "699.99"],
+        ],
+    );
+
+    // Test validating multiple files with pretty JSON output
+    let mut cmd = wrk.command("validate");
+    cmd.arg("--pretty-json").arg("file1.csv").arg("file2.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    assert!(got.contains("✅ All 2 files are valid."));
+
+    // Check that pretty JSON output is produced for each file
+    let output = wrk.output(&mut cmd);
+    let stdout_str = String::from_utf8_lossy(&output.stdout);
+    assert!(stdout_str.contains("{\n  \"delimiter_char\": \",\""));
+    assert!(stdout_str.contains("\"num_records\": 2"));
+}
+
+#[test]
+fn validate_multiple_files_quiet_mode() {
+    let wrk = Workdir::new("validate_multiple_files_quiet_mode").flexible(true);
+
+    // Create multiple test CSV files
+    wrk.create(
+        "file1.csv",
+        vec![svec!["id", "name"], svec!["1", "John"], svec!["2", "Jane"]],
+    );
+
+    wrk.create(
+        "file2.csv",
+        vec![
+            svec!["product", "price"],
+            svec!["Laptop", "999.99"],
+            svec!["Phone", "699.99"],
+        ],
+    );
+
+    // Test validating multiple files in quiet mode
+    let mut cmd = wrk.command("validate");
+    cmd.arg("--quiet").arg("file1.csv").arg("file2.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    // In quiet mode, there should be no output to stderr
+    let got: String = wrk.output_stderr(&mut cmd);
+    // The output might be "No error" if there's no stderr output
+    assert!(got == "" || got == "No error");
+}
+
+#[test]
+fn validate_multiple_files_with_mixed_delimiters() {
+    let wrk = Workdir::new("validate_multiple_files_with_mixed_delimiters").flexible(true);
+
+    // Create CSV file with comma delimiter
+    wrk.create(
+        "comma.csv",
+        vec![
+            svec!["id", "name", "age"],
+            svec!["1", "John", "25"],
+            svec!["2", "Jane", "30"],
+        ],
+    );
+
+    // Create TSV file with tab delimiter
+    wrk.create(
+        "tab.tsv",
+        vec![
+            svec!["id\tname\tage"],
+            svec!["1\tJohn\t25"],
+            svec!["2\tJane\t30"],
+        ],
+    );
+
+    // Test validating multiple files with different delimiters
+    let mut cmd = wrk.command("validate");
+    cmd.arg("comma.csv").arg("tab.tsv");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    assert!(got.contains("✅ All 2 files are valid."));
+}
+
+#[test]
+fn validate_multiple_files_no_headers() {
+    let wrk = Workdir::new("validate_multiple_files_no_headers").flexible(true);
+
+    // Create files without headers
+    wrk.create(
+        "file1.csv",
+        vec![svec!["1", "John", "25"], svec!["2", "Jane", "30"]],
+    );
+
+    wrk.create(
+        "file2.csv",
+        vec![
+            svec!["Laptop", "999.99", "50"],
+            svec!["Phone", "699.99", "100"],
+        ],
+    );
+
+    // Test validating multiple files without headers
+    let mut cmd = wrk.command("validate");
+    cmd.arg("--no-headers").arg("file1.csv").arg("file2.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    assert!(got.contains("✅ All 2 files are valid."));
+}
+
+#[test]
+fn validate_single_file_backward_compatibility() {
+    let wrk = Workdir::new("validate_single_file_backward_compatibility").flexible(true);
+
+    // Create a single CSV file
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["id", "name", "age"],
+            svec!["1", "John", "25"],
+            svec!["2", "Jane", "30"],
+        ],
+    );
+
+    // Test that single file validation still works exactly as before
+    let mut cmd = wrk.command("validate");
+    cmd.arg("data.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    let got_stderr: String = wrk.output_stderr(&mut cmd);
+    let output = wrk.output(&mut cmd);
+    let got_stdout = String::from_utf8_lossy(&output.stdout);
+
+    let expected = "Valid: 3 Columns: (\"id\", \"name\", \"age\"); Records: 2; Delimiter: ,";
+    // The output might be on stdout instead of stderr
+    if got_stderr.contains("No error") {
+        assert_eq!(got_stdout.trim(), expected);
+    } else {
+        assert_eq!(got_stderr, expected);
+    }
+}
+
+#[test]
+fn validate_single_file_error_backward_compatibility() {
+    let wrk = Workdir::new("validate_single_file_error_backward_compatibility").flexible(true);
+
+    // Create a single CSV file with invalid data
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["id", "name", "age"],
+            svec!["1", "John", "25"],
+            svec!["2", "Jane"], // Missing age field
+        ],
+    );
+
+    // Test that single file error handling still works exactly as before
+    let mut cmd = wrk.command("validate");
+    cmd.arg("data.csv");
+
+    wrk.assert_err(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    // The exact byte position may vary, so we check for key components
+    assert!(got.contains("Validation error: CSV error: record 2 (line: 3, byte:"));
+    assert!(got.contains("found record with 2 fields, but the previous record has 3 fields."));
+    assert!(got.contains("Use `qsv fixlengths` to fix record length issues."));
+}
+
+#[test]
+fn validate_json_schema_still_single_file() {
+    let wrk = Workdir::new("validate_json_schema_still_single_file").flexible(true);
+
+    // Create a JSON schema
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "name": { "type": "string" },
+                "age": { "type": "integer" }
+            }
+        }"#,
+    );
+
+    // Create a CSV file
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["id", "name", "age"],
+            svec!["1", "John", "25"],
+            svec!["2", "Jane", "30"],
+        ],
+    );
+
+    // Test that JSON Schema validation still works with single file
+    let mut cmd = wrk.command("validate");
+    cmd.arg("data.csv").arg("schema.json");
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "All 2 records valid.\n";
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_json_schema_rejects_multiple_files() {
+    let wrk = Workdir::new("validate_json_schema_rejects_multiple_files").flexible(true);
+
+    // Create a JSON schema
+    wrk.create_from_string(
+        "schema.json",
+        r#"{
+            "$schema": "https://json-schema.org/draft/2020-12/schema",
+            "type": "object",
+            "properties": {
+                "id": { "type": "string" },
+                "name": { "type": "string" }
+            }
+        }"#,
+    );
+
+    // Create multiple CSV files
+    wrk.create("file1.csv", vec![svec!["id", "name"], svec!["1", "John"]]);
+
+    wrk.create("file2.csv", vec![svec!["id", "name"], svec!["2", "Jane"]]);
+
+    // Test that JSON Schema validation rejects multiple files
+    let mut cmd = wrk.command("validate");
+    cmd.arg("file1.csv").arg("file2.csv").arg("schema.json");
+
+    wrk.assert_err(&mut cmd);
+
+    let got: String = wrk.output_stderr(&mut cmd);
+    let expected = "JSON Schema validation only supports a single input file. Use RFC 4180 \
+                    validation mode for multiple files.\n";
+    assert_eq!(got, expected);
+}
